@@ -2,6 +2,7 @@ package git
 
 import (
 	"fmt"
+	"os/exec"
 	"regexp"
 	"strconv"
 	"strings"
@@ -422,96 +423,103 @@ func (w *Walker) Repository() *git.Repository {
 }
 
 // IsWorkingDirectoryClean checks if the working directory has any uncommitted changes
+// Uses native git CLI instead of go-git to properly handle worktree scenarios
 func (w *Walker) IsWorkingDirectoryClean() (bool, error) {
 	worktree, err := w.repo.Worktree()
 	if err != nil {
 		return false, fmt.Errorf("failed to get worktree: %w", err)
 	}
 
-	status, err := worktree.Status()
+	worktreePath := worktree.Filesystem.Root()
+
+	// Use native git status --porcelain to avoid go-git worktree issues
+	// go-git's status API has known bugs with linked worktrees
+	cmd := exec.Command("git", "status", "--porcelain")
+	cmd.Dir = worktreePath
+
+	output, err := cmd.Output()
 	if err != nil {
 		return false, fmt.Errorf("failed to get git status: %w", err)
 	}
 
-	return status.IsClean(), nil
+	// If output is empty, working directory is clean
+	return len(strings.TrimSpace(string(output))) == 0, nil
 }
 
 // GetStatusDetails returns a detailed status of the working directory
+// Uses native git CLI instead of go-git to properly handle worktree scenarios
 func (w *Walker) GetStatusDetails() (string, error) {
 	worktree, err := w.repo.Worktree()
 	if err != nil {
 		return "", fmt.Errorf("failed to get worktree: %w", err)
 	}
 
-	status, err := worktree.Status()
+	worktreePath := worktree.Filesystem.Root()
+
+	// Use native git status --porcelain to avoid go-git worktree issues
+	cmd := exec.Command("git", "status", "--porcelain")
+	cmd.Dir = worktreePath
+
+	output, err := cmd.Output()
 	if err != nil {
 		return "", fmt.Errorf("failed to get git status: %w", err)
 	}
 
-	if status.IsClean() {
-		return "", nil
-	}
-
-	var details strings.Builder
-	for file, fileStatus := range status {
-		details.WriteString(fmt.Sprintf("  %c%c %s\n", fileStatus.Staging, fileStatus.Worktree, file))
-	}
-
-	return details.String(), nil
+	return string(output), nil
 }
 
 // AddFile adds a file to the git index
+// Uses native git CLI instead of go-git to properly handle worktree scenarios
 func (w *Walker) AddFile(filename string) error {
 	worktree, err := w.repo.Worktree()
 	if err != nil {
 		return fmt.Errorf("failed to get worktree: %w", err)
 	}
 
-	_, err = worktree.Add(filename)
+	worktreePath := worktree.Filesystem.Root()
+
+	// Use native git add command to avoid go-git worktree issues
+	cmd := exec.Command("git", "add", filename)
+	cmd.Dir = worktreePath
+
+	output, err := cmd.CombinedOutput()
 	if err != nil {
-		return fmt.Errorf("failed to add file %s: %w", filename, err)
+		return fmt.Errorf("failed to add file %s: %w (output: %s)", filename, err, string(output))
 	}
 
 	return nil
 }
 
 // CommitChanges creates a commit with the given message
+// Uses native git CLI instead of go-git to properly handle worktree scenarios
 func (w *Walker) CommitChanges(message string) (plumbing.Hash, error) {
 	worktree, err := w.repo.Worktree()
 	if err != nil {
 		return plumbing.ZeroHash, fmt.Errorf("failed to get worktree: %w", err)
 	}
 
-	// Get git config for author information
-	cfg, err := w.repo.Config()
+	worktreePath := worktree.Filesystem.Root()
+
+	// Use native git commit command to avoid go-git worktree issues
+	cmd := exec.Command("git", "commit", "-m", message)
+	cmd.Dir = worktreePath
+
+	output, err := cmd.CombinedOutput()
 	if err != nil {
-		return plumbing.ZeroHash, fmt.Errorf("failed to get git config: %w", err)
+		return plumbing.ZeroHash, fmt.Errorf("failed to commit: %w (output: %s)", err, string(output))
 	}
 
-	var authorName, authorEmail string
-	if cfg.User.Name != "" {
-		authorName = cfg.User.Name
-	} else {
-		authorName = "Changelog Bot"
-	}
-	if cfg.User.Email != "" {
-		authorEmail = cfg.User.Email
-	} else {
-		authorEmail = "bot@changelog.local"
-	}
+	// Get the commit hash from HEAD using native git to avoid go-git worktree issues
+	hashCmd := exec.Command("git", "rev-parse", "HEAD")
+	hashCmd.Dir = worktreePath
 
-	commit, err := worktree.Commit(message, &git.CommitOptions{
-		Author: &object.Signature{
-			Name:  authorName,
-			Email: authorEmail,
-			When:  time.Now(),
-		},
-	})
+	hashOutput, err := hashCmd.Output()
 	if err != nil {
-		return plumbing.ZeroHash, fmt.Errorf("failed to commit: %w", err)
+		return plumbing.ZeroHash, fmt.Errorf("failed to get HEAD after commit: %w", err)
 	}
 
-	return commit, nil
+	hashStr := strings.TrimSpace(string(hashOutput))
+	return plumbing.NewHash(hashStr), nil
 }
 
 // PushToRemote pushes the current branch to the remote repository
