@@ -10,9 +10,9 @@ import (
 	"strings"
 
 	"github.com/danielmiessler/fabric/internal/chat"
-	"github.com/danielmiessler/fabric/internal/plugins"
-
 	"github.com/danielmiessler/fabric/internal/domain"
+	"github.com/danielmiessler/fabric/internal/plugins"
+	"github.com/danielmiessler/fabric/internal/plugins/ai/geminicommon"
 	"google.golang.org/genai"
 )
 
@@ -29,10 +29,6 @@ const (
 )
 
 const (
-	citationHeader    = "\n\n## Sources\n\n"
-	citationSeparator = "\n"
-	citationFormat    = "- [%s](%s)"
-
 	errInvalidLocationFormat = "invalid search location format %q: must be timezone (e.g., 'America/Los_Angeles') or language code (e.g., 'en-US')"
 	locationSeparator        = "/"
 	langCodeSeparator        = "_"
@@ -50,10 +46,7 @@ func NewClient() (ret *Client) {
 	vendorName := "Gemini"
 	ret = &Client{}
 
-	ret.PluginBase = &plugins.PluginBase{
-		Name:          vendorName,
-		EnvNamePrefix: plugins.BuildEnvVariablePrefix(vendorName),
-	}
+	ret.PluginBase = plugins.NewVendorPluginBase(vendorName, nil)
 
 	ret.ApiKey = ret.PluginBase.AddSetupQuestion("API key", true)
 
@@ -111,7 +104,7 @@ func (o *Client) Send(ctx context.Context, msgs []*chat.ChatCompletionMessage, o
 	}
 
 	// Convert messages to new SDK format
-	contents := o.convertMessages(msgs)
+	contents := geminicommon.ConvertMessages(msgs)
 
 	cfg, err := o.buildGenerateContentConfig(opts)
 	if err != nil {
@@ -125,11 +118,11 @@ func (o *Client) Send(ctx context.Context, msgs []*chat.ChatCompletionMessage, o
 	}
 
 	// Extract text from response
-	ret = o.extractTextFromResponse(response)
+	ret = geminicommon.ExtractTextWithCitations(response)
 	return
 }
 
-func (o *Client) SendStream(msgs []*chat.ChatCompletionMessage, opts *domain.ChatOptions, channel chan string) (err error) {
+func (o *Client) SendStream(msgs []*chat.ChatCompletionMessage, opts *domain.ChatOptions, channel chan domain.StreamUpdate) (err error) {
 	ctx := context.Background()
 	defer close(channel)
 
@@ -142,7 +135,7 @@ func (o *Client) SendStream(msgs []*chat.ChatCompletionMessage, opts *domain.Cha
 	}
 
 	// Convert messages to new SDK format
-	contents := o.convertMessages(msgs)
+	contents := geminicommon.ConvertMessages(msgs)
 
 	cfg, err := o.buildGenerateContentConfig(opts)
 	if err != nil {
@@ -154,13 +147,30 @@ func (o *Client) SendStream(msgs []*chat.ChatCompletionMessage, opts *domain.Cha
 
 	for response, err := range stream {
 		if err != nil {
-			channel <- fmt.Sprintf("Error: %v\n", err)
+			channel <- domain.StreamUpdate{
+				Type:    domain.StreamTypeError,
+				Content: fmt.Sprintf("Error: %v", err),
+			}
 			return err
 		}
 
-		text := o.extractTextFromResponse(response)
+		text := geminicommon.ExtractTextWithCitations(response)
 		if text != "" {
-			channel <- text
+			channel <- domain.StreamUpdate{
+				Type:    domain.StreamTypeContent,
+				Content: text,
+			}
+		}
+
+		if response.UsageMetadata != nil {
+			channel <- domain.StreamUpdate{
+				Type: domain.StreamTypeUsage,
+				Usage: &domain.UsageMetadata{
+					InputTokens:  int(response.UsageMetadata.PromptTokenCount),
+					OutputTokens: int(response.UsageMetadata.CandidatesTokenCount),
+					TotalTokens:  int(response.UsageMetadata.TotalTokenCount),
+				},
+			}
 		}
 	}
 
@@ -201,10 +211,14 @@ func parseThinkingConfig(level domain.ThinkingLevel) (*genai.ThinkingConfig, boo
 func (o *Client) buildGenerateContentConfig(opts *domain.ChatOptions) (*genai.GenerateContentConfig, error) {
 	temperature := float32(opts.Temperature)
 	topP := float32(opts.TopP)
+	var maxTokens int32
+	if opts.MaxTokens > 0 {
+		maxTokens = int32(opts.MaxTokens)
+	}
 	cfg := &genai.GenerateContentConfig{
 		Temperature:     &temperature,
 		TopP:            &topP,
-		MaxOutputTokens: int32(opts.ModelContextLength),
+		MaxOutputTokens: maxTokens,
 	}
 
 	if opts.Search {
@@ -435,113 +449,3 @@ func (o *Client) generateWAVFile(pcmData []byte) ([]byte, error) {
 
 	return result, nil
 }
-
-// convertMessages converts fabric chat messages to genai Content format
-func (o *Client) convertMessages(msgs []*chat.ChatCompletionMessage) []*genai.Content {
-	var contents []*genai.Content
-
-	for _, msg := range msgs {
-		content := &genai.Content{Parts: []*genai.Part{}}
-
-		switch msg.Role {
-		case chat.ChatMessageRoleAssistant:
-			content.Role = "model"
-		case chat.ChatMessageRoleUser:
-			content.Role = "user"
-		case chat.ChatMessageRoleSystem, chat.ChatMessageRoleDeveloper, chat.ChatMessageRoleFunction, chat.ChatMessageRoleTool:
-			// Gemini's API only accepts "user" and "model" roles.
-			// Map all other roles to "user" to preserve instruction context.
-			content.Role = "user"
-		default:
-			content.Role = "user"
-		}
-
-		if strings.TrimSpace(msg.Content) != "" {
-			content.Parts = append(content.Parts, &genai.Part{Text: msg.Content})
-		}
-
-		// Handle multi-content messages (images, etc.)
-		for _, part := range msg.MultiContent {
-			switch part.Type {
-			case chat.ChatMessagePartTypeText:
-				content.Parts = append(content.Parts, &genai.Part{Text: part.Text})
-			case chat.ChatMessagePartTypeImageURL:
-				// TODO: Handle image URLs if needed
-				// This would require downloading and converting to inline data
-			}
-		}
-
-		contents = append(contents, content)
-	}
-
-	return contents
-}
-
-// extractTextFromResponse extracts text content from the response and appends
-// any web citations in a standardized format.
-func (o *Client) extractTextFromResponse(response *genai.GenerateContentResponse) string {
-	if response == nil {
-		return ""
-	}
-
-	text := o.extractTextParts(response)
-	citations := o.extractCitations(response)
-	if len(citations) > 0 {
-		return text + citationHeader + strings.Join(citations, citationSeparator)
-	}
-	return text
-}
-
-func (o *Client) extractTextParts(response *genai.GenerateContentResponse) string {
-	var builder strings.Builder
-	for _, candidate := range response.Candidates {
-		if candidate == nil || candidate.Content == nil {
-			continue
-		}
-		for _, part := range candidate.Content.Parts {
-			if part != nil && part.Text != "" {
-				builder.WriteString(part.Text)
-			}
-		}
-	}
-	return builder.String()
-}
-
-func (o *Client) extractCitations(response *genai.GenerateContentResponse) []string {
-	if response == nil || len(response.Candidates) == 0 {
-		return nil
-	}
-
-	citationMap := make(map[string]bool)
-	var citations []string
-	for _, candidate := range response.Candidates {
-		if candidate == nil || candidate.GroundingMetadata == nil {
-			continue
-		}
-		chunks := candidate.GroundingMetadata.GroundingChunks
-		if len(chunks) == 0 {
-			continue
-		}
-		for _, chunk := range chunks {
-			if chunk == nil || chunk.Web == nil {
-				continue
-			}
-			uri := chunk.Web.URI
-			title := chunk.Web.Title
-			if uri == "" || title == "" {
-				continue
-			}
-			var keyBuilder strings.Builder
-			keyBuilder.WriteString(uri)
-			keyBuilder.WriteByte('|')
-			keyBuilder.WriteString(title)
-			key := keyBuilder.String()
-			if !citationMap[key] {
-				citationMap[key] = true
-				citationText := fmt.Sprintf(citationFormat, title, uri)
-				citations = append(citations, citationText)
-			}
-		}
-	}
-	return citations
-}
