@@ -60,6 +60,16 @@ func (c *Client) ListModels() ([]string, error) {
 	return c.DirectlyGetModels(context.Background())
 }
 
+// NeedsRawMode overrides the parent implementation to handle provider-specific raw mode requirements
+func (c *Client) NeedsRawMode(modelName string) bool {
+	// MiniMax models require raw mode for proper message formatting
+	if c.GetName() == "MiniMax" {
+		return true
+	}
+	// Fall back to parent OpenAI client implementation for other providers
+	return c.Client.NeedsRawMode(modelName)
+}
+
 // getStaticModels returns a predefined list of models for providers that don't support model discovery
 func (c *Client) getStaticModels(modelsKey string) ([]string, error) {
 	switch modelsKey {
@@ -117,6 +127,12 @@ func (c *Client) getStaticModels(modelsKey string) ([]string, error) {
 			"zai-org/glm-4.5",
 			"zai-org/glm-4.6",
 		}, nil
+	case "static:minimax":
+		return []string{
+			"MiniMax-M2",
+			"MiniMax-M2.1",
+			"MiniMax-M2.1-lightning",
+		}, nil
 	default:
 		return nil, fmt.Errorf("unknown static model list: %s", modelsKey)
 	}
@@ -145,6 +161,11 @@ var ProviderMap = map[string]ProviderConfig{
 		ModelsURL:           "https://models.github.ai/catalog", // FetchModelsDirectly will append /models
 		ImplementsResponses: false,
 	},
+	"Infermatic": {
+		Name:                "Infermatic",
+		BaseURL:             "https://api.totalgpt.ai/v1",
+		ImplementsResponses: false,
+	},
 	"GrokAI": {
 		Name:                "GrokAI",
 		BaseURL:             "https://api.x.ai/v1",
@@ -167,7 +188,8 @@ var ProviderMap = map[string]ProviderConfig{
 	},
 	"MiniMax": {
 		Name:                "MiniMax",
-		BaseURL:             "https://api.minimaxi.com/v1",
+		BaseURL:             "https://api.minimax.io/v1",
+		ModelsURL:           "static:minimax",
 		ImplementsResponses: false,
 	},
 	"Mistral": {
@@ -175,6 +197,11 @@ var ProviderMap = map[string]ProviderConfig{
 		BaseURL:             "https://api.mistral.ai/v1",
 		ImplementsResponses: false,
 	},
+	"Novita AI": {
+		Name:                "Novita AI",
+		BaseURL:             "https://api.novita.ai/openai/v1",
+		ImplementsResponses: false,
+	},
 	"OpenRouter": {
 		Name:                "OpenRouter",
 		BaseURL:             "https://openrouter.ai/api/v1",
@@ -206,6 +233,11 @@ var ProviderMap = map[string]ProviderConfig{
 		ModelsURL:           "static:abacus", // Special marker for static model list
 		ImplementsResponses: false,
 	},
+	"Mammouth": {
+		Name:                "Mammouth",
+		BaseURL:             "https://api.mammouth.ai/v1",
+		ImplementsResponses: false,
+	},
 }
 
 // GetProviderByName returns the provider configuration for a given name with O(1) lookup
