@@ -12,7 +12,7 @@ import (
 type Vendor interface {
 	plugins.Plugin
 	ListModels() ([]string, error)
-	SendStream([]*chat.ChatCompletionMessage, *domain.ChatOptions, chan string) error
+	SendStream([]*chat.ChatCompletionMessage, *domain.ChatOptions, chan domain.StreamUpdate) error
 	Send(context.Context, []*chat.ChatCompletionMessage, *domain.ChatOptions) (string, error)
 	NeedsRawMode(modelName string) bool
 }
