@@ -17,6 +17,15 @@ func NewModelsHandler(r *gin.Engine, vendorManager *ai.VendorsManager) {
 	r.GET("/models/names", handler.GetModelNames)
 }
 
+// GetModelNames godoc
+// @Summary List all available models
+// @Description Get a list of all available AI models grouped by vendor
+// @Tags models
+// @Produce json
+// @Success 200 {object} map[string]interface{} "Returns models (array) and vendors (map)"
+// @Failure 500 {object} map[string]string
+// @Security ApiKeyAuth
+// @Router /models/names [get]
 func (h *ModelsHandler) GetModelNames(c *gin.Context) {
 	vendorsModels, err := h.vendorManager.GetModels()
 	if err != nil {
@@ -24,7 +33,7 @@ func (h *ModelsHandler) GetModelNames(c *gin.Context) {
 		return
 	}
 
-	response := make(map[string]interface{})
+	response := make(map[string]any)
 	vendors := make(map[string][]string)
 
 	for _, groupItems := range vendorsModels.GroupsItems {
